#!/usr/bin/perl

use strict;
use warnings FATAL => 'all';
use Getopt::Long;

my $gene_id_pattern = "ENSG\\d+";
my $transcript_id_pattern = "ENST\\d+";

GetOptions
(
        'g|gene_id_pattern=s'      => \$gene_id_pattern,
        't|transcript_id_pattern=s'      => \$transcript_id_pattern
);

# Count the number of paired end sequences aligning to each gene

my %gene_counts;

while (my $line = <>)
{
	chomp($line);
	
	next if $line =~ /^\@/;
	
	my @fields = split /\t/, $line;

	my $reference = $fields[2];

	next unless $reference =~ /($gene_id_pattern)\|($transcript_id_pattern)/;
	my $gene = $1;
	my $transcript = $2;

	$gene_counts{$gene} += 0.5;
}

foreach my $gene (keys %gene_counts)
{
	print $gene."\t".$gene_counts{$gene}."\n";
}

